==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sl" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Ustvari ravnino slike...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Ustvari ravninsko sliko v prostoru 3D</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="unfinished">create a planar image in the 3D space</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Odpri...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Odpri pogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedoločena vrsta barvnega prostora za ogled slike</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Oblika slike v slikovnih točkah</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Ravnina slike</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Prilagodi sliko</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Raztegni sliko na velikost pogleda</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Merilo &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaži sliko v merilu 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation type="unfinished">&amp;Original color</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="unfinished">Display the image with its original color(s)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="unfinished">&amp;Brightened color</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="unfinished">Display the image with brightened color(s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Pripravljeni …</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>povečava</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>izven slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation type="unfinished">Image viewer</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Izberite sliko za odpiranje</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Vse datoteke</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Napaka pri odpiranju slike</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Izbrane slike ni bilo mogoče naložiti</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Napaka pri odpiranju slike</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Izbrane slike ni bilo mogoče naložiti</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sl" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Ustvari ravnino slike...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Ustvari ravninsko sliko v prostoru 3D</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="unfinished">create a planar image in the 3D space</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Odpri...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Odpri pogled slike</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Povečava...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Velikost slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedoločena vrsta barvnega prostora za ogled slike</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Oblika slike v slikovnih točkah</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Ravnina slike</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Prilagodi sliko</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Raztegni sliko na velikost pogleda</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Merilo &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaži sliko v merilu 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation type="unfinished">&amp;Original color</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="unfinished">Display the image with its original color(s)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="unfinished">&amp;Brightened color</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="unfinished">Display the image with brightened color(s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Pripravljeni …</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>povečava</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>izven slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation type="unfinished">Image viewer</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Izberite sliko za odpiranje</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Slike</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Vse datoteke</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Napaka pri odpiranju slike</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Izbrane slike ni bilo mogoče naložiti</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Napaka pri odpiranju slike</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Izbrane slike ni bilo mogoče naložiti</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>
